@@ -397,7 +397,6 @@ currentUserIsMemberOfGroupSID (BYTE nSubAuthorityCount,
   DWORD dwLength = 0;
   PTOKEN_GROUPS ptg = NULL;
   int rv = -1;
-  int i;
 
   if (!AllocateAndInitializeSid (&nt_auth,
 				       nSubAuthorityCount,
@@ -497,7 +496,6 @@ uidMatchesAccountSID (uid_t uid,
   SID_IDENTIFIER_AUTHORITY nt_auth = SECURITY_NT_AUTHORITY;
   PSID requestedSID = NULL;
   PSID userSID = NULL;
-  DWORD dwLength = 0;
   int rv = -1;
 
   if (!AllocateAndInitializeSid (&nt_auth,
@@ -552,7 +550,6 @@ uidIsMemberOfGroupSID (uid_t uid,
   SID_IDENTIFIER_AUTHORITY nt_auth = SECURITY_NT_AUTHORITY;
   PSID requestedSID = NULL;
   PSID userSID = NULL;
-  DWORD dwLength = 0;
   int rv = -1;
 
   if (!AllocateAndInitializeSid (&nt_auth,
@@ -874,13 +871,11 @@ getUserInfoForUID (uid_t uid,
 		   DWORD level,
 		   LPBYTE * bufptr, LPWSTR * uni_servername, int *matchedName)
 {
-  DWORD dwLength = 0;
   int rv = -1;
   struct passwd *pw;
   char name[UNLEN + 1];
   WCHAR uni_name[2 * (UNLEN + 1)];
   char domain[INTERNET_MAX_HOST_NAME_LENGTH + 1];
-  WCHAR uni_domain[2 * (INTERNET_MAX_HOST_NAME_LENGTH + 1)];
   char servername[256];
 
   if (!uni_servername)
@@ -978,8 +973,7 @@ getUserInfoForUID (uid_t uid,
 	  /* if we had a domain, then try again locally. if we didn't have a
 	     domain, then the initial call WAS local */
 	  if (NetUserGetInfo
-	      (*uni_servername, (LPWSTR) & uni_name, level,
-	       bufptr) != NERR_Success)
+	      (NULL, (LPWSTR) & uni_name, level, bufptr) != NERR_Success)
 	    {
 	      syslog (LOG_ERR,
 		      "unable to obtain user info for %s [tried domain controller %s and localhost]\n",
